#!/bin/sh
#-----------
# File:      nanocop_casc.sh
# Version:   0.2
# Date:      3 July 2018
#-----------
# Purpose:   makes output of nanoCoP compliant for CASC
#            (replaces "Non-Theorem" by "CounterSatisfiable"!)
# Usage:     ./nanocop_casc.sh <problem file> [<time limit>]
# Author:    Jens Otten
# Web:       www.leancop.de/nanocop
#-----------

cd `dirname $0`

OUTCAS=TMP_CASC_nanocop_`date +%F_%T_%N`
trap "rm $OUTCAS; exit 2" ALRM XCPU INT QUIT TERM
./nanocop.sh $1 $2 > $OUTCAS
EXIT_STATUS=$?

RESULT1=`cat $OUTCAS | head -2 | egrep ' Theorem'`
RESULT2=`cat $OUTCAS | head -2 | egrep ' Unsatisfiable| Satisfiable'`
RESULT3=`cat $OUTCAS | head -2 | egrep ' Non-Theorem'`
if [ -n "$RESULT1" ];
  then echo "% SZS status $RESULT1 for $RESULT1" | cut -d' ' -f-3,7-9
fi
if [ -n "$RESULT2" ];
  then echo "% SZS status $RESULT2 for $RESULT2" | cut -d' ' -f-3,6-8
fi
if [ -n "$RESULT3" ]
  then echo "% SZS status CounterSatisfiable for $RESULT3" | cut -d' ' -f-6
fi

PROOFA=`cat $OUTCAS | head -3 | egrep 'Start of proof'`
if [ -n "$PROOFA" ]
then
  echo "% SZS output start Proof $PROOFA" | cut -d' ' -f-5,9-
  echo
  echo "- the following list represents a non-clausal connection proof"
  echo "  (a tree in which each node is labelled with a nested clause)"
  echo "- I^V is a skolem term f_I(V) for variable list V"
  echo "- (I^K)^V:C is the (nested) clause C with index (I^K)^V, in which"
  echo "  I is the unique index of C, K distinguishes different copies"
  echo "  of C, and V is the list of (instantiated) variables in C"
  cat $OUTCAS | \
    egrep -v ' Theorem| Unsatisfiable| Non-Theorem| Satisfiable| of proof for'
  PROOFB=`cat $OUTCAS | tail -2 | egrep 'End of proof'`
  echo ""
  echo "% SZS output end Proof $PROOFB" | cut -d' ' -f-5,9-
fi

rm $OUTCAS
exit $EXIT_STATUS

